@@ -42,6 +42,7 @@ def bootstrap(
     scm_bucket_name,
     scm_object_key,
     scm_skip_creation_of_repo,
+    should_validate,
 ):
     click.echo("Starting bootstrap")
     should_use_eventbridge = config.get_should_use_eventbridge(
@@ -150,6 +151,7 @@ def bootstrap(
         ),
         with_manual_approvals,
         scm_skip_creation_of_repo,
+        should_validate,
     ).to_yaml(clean_up=True)
 
     args = {
@@ -223,6 +225,9 @@ def bootstrap(
                 "UsePreviousValue": False,
             },
         ],
+        "ShouldDeleteRollbackComplete": config.get_should_delete_rollback_complete_stacks(
+            puppet_account_id
+        ),
     }
     with betterboto_client.ClientContextManager("cloudformation") as cloudformation:
         click.echo("Creating {}".format(constants.BOOTSTRAP_STACK_NAME))
